API References
==============

This is the reference for classes (``CamelCase`` names) and functions
(``underscore_case`` names) of ``callcut`` grouped thematically.

.. toctree::
    :maxdepth: 0

    io.rst
    extractors.rst
    nn.rst
    training.rst
    evaluation.rst
    pipeline.rst
    logging.rst
